diff graal/GraalCompiler/src/com/sun/c1x/ir/Switch.java @ 2741:a3cd5eb68837

more GraphBuilder cleanup, moved mergeOrClone to GraphBuilder
author Lukas Stadler <lukas.stadler@jku.at>
date Fri, 20 May 2011 11:11:33 +0200
parents a0dd2b907806
children 6048da340364
line wrap: on
line diff
--- a/graal/GraalCompiler/src/com/sun/c1x/ir/Switch.java	Fri May 20 10:16:39 2011 +0200
+++ b/graal/GraalCompiler/src/com/sun/c1x/ir/Switch.java	Fri May 20 11:11:33 2011 +0200
@@ -63,12 +63,12 @@
      * Constructs a new Switch.
      * @param value the instruction that provides the value to be switched over
      * @param successors the list of successors of this switch
      * @param stateBefore the state before the switch
      * @param isSafepoint {@code true} if this switch is a safepoint
      * @param graph
      */
-    public Switch(Value value, List<BlockBegin> successors, FrameState stateBefore, int inputCount, int successorCount, Graph graph) {
-        super(CiKind.Illegal, stateBefore, successors, inputCount + INPUT_COUNT, successorCount + SUCCESSOR_COUNT, graph);
+    public Switch(Value value, List<BlockBegin> successors, FrameState stateAfter, int inputCount, int successorCount, Graph graph) {
+        super(CiKind.Illegal, stateAfter, successors, inputCount + INPUT_COUNT, successorCount + SUCCESSOR_COUNT, graph);
         setValue(value);
     }
@@ -63,12 +63,12 @@
      * @param value the instruction that provides the value to be switched over
      * @param successors the list of successors of this switch
-     * @param stateBefore the state before the switch
+     * @param stateAfter the state after the switch
      * @param isSafepoint {@code true} if this switch is a safepoint
      * @param graph